# GRAFX 


<div align="center">
  
**An Open-Source Library for Audio Processing Graphs in PyTorch**


[Documentation](https://sh-lee97.github.io/grafx) | [Technical Paper (arXiv)]()

`pip install grafx`

<br>
<img src="sphinx-doc/source/imgs/cambridge_RememberDecember_CUNextTime.svg">

</div>
